@@ -138,16 +138,9 @@ public class HeaderReader {
     CentralDirectory centralDirectory = new CentralDirectory();
     List<FileHeader> fileHeaders = new ArrayList<>();
 
-    long offSetStartCentralDir = getOffsetCentralDirectory(zipModel);
+    long offSetStartCentralDir = HeaderUtil.getOffsetStartOfCentralDirectory(zipModel);
     long centralDirEntryCount = getNumberOfEntriesInCentralDirectory(zipModel);
-
-    if (zipModel.isZip64Format()) {
-      offSetStartCentralDir = zipModel.getZip64EndOfCentralDirectoryRecord()
-          .getOffsetStartCentralDirectoryWRTStartDiskNumber();
-      centralDirEntryCount = (int) zipModel.getZip64EndOfCentralDirectoryRecord()
-          .getTotalNumberOfEntriesInCentralDirectory();
-    }
-
+    
     zip4jRaf.seek(offSetStartCentralDir);
 
     byte[] shortBuff = new byte[2];
@@ -701,14 +694,6 @@ public class HeaderReader {
     return null;
   }
 
-  private long getOffsetCentralDirectory(ZipModel zipModel) {
-    if (zipModel.isZip64Format()) {
-      return zipModel.getZip64EndOfCentralDirectoryRecord().getOffsetStartCentralDirectoryWRTStartDiskNumber();
-    }
-
-    return zipModel.getEndOfCentralDirectoryRecord().getOffsetOfStartOfCentralDirectory();
-  }
-
   private long getNumberOfEntriesInCentralDirectory(ZipModel zipModel) {
     if (zipModel.isZip64Format()) {
       return zipModel.getZip64EndOfCentralDirectoryRecord().getTotalNumberOfEntriesInCentralDirectory();
