@@ -194,8 +194,11 @@ public class ZipInputStream extends InputStream {
 
     if (localFileHeader.getEncryptionMethod() == EncryptionMethod.AES) {
       return new AesCipherInputStream(zipEntryInputStream, localFileHeader, password);
-    } else {
+    } else if (localFileHeader.getEncryptionMethod() == EncryptionMethod.ZIP_STANDARD) {
       return new ZipStandardCipherInputStream(zipEntryInputStream, localFileHeader, password);
+    } else {
+      final String message = String.format("Entry [%s] Strong Encryption not supported", localFileHeader.getFileName());
+      throw new ZipException(message, ZipException.Type.UNSUPPORTED_ENCRYPTION);
     }
   }
 
@@ -290,7 +293,7 @@ public class ZipInputStream extends InputStream {
     }
 
     if (localFileHeader.getEncryptionMethod().equals(EncryptionMethod.AES)) {
-      return InternalZipConstants.AES_AUTH_LENGTH + AESDecrypter.PASSWORD_VERIFIER_LENGTH
+      return InternalZipConstants.AES_AUTH_LENGTH + InternalZipConstants.AES_PASSWORD_VERIFIER_LENGTH
           + localFileHeader.getAesExtraDataRecord().getAesKeyStrength().getSaltLength();
     } else if (localFileHeader.getEncryptionMethod().equals(EncryptionMethod.ZIP_STANDARD)) {
       return InternalZipConstants.STD_DEC_HDR_SIZE;
