@@ -6,17 +6,20 @@ import net.lingala.zip4j.model.FileHeader;
 import net.lingala.zip4j.model.ZipModel;
 import net.lingala.zip4j.progress.ProgressMonitor;
 import net.lingala.zip4j.tasks.ExtractAllFilesTask.ExtractAllFilesTaskParameters;
+import net.lingala.zip4j.util.UnzipUtil;
 
 import java.io.IOException;
 import java.nio.charset.Charset;
 
+import static net.lingala.zip4j.headers.HeaderUtil.getTotalUncompressedSizeOfAllFileHeaders;
+
 public class ExtractAllFilesTask extends AbstractExtractFileTask<ExtractAllFilesTaskParameters> {
 
   private char[] password;
   private SplitInputStream splitInputStream;
 
-  public ExtractAllFilesTask(ProgressMonitor progressMonitor, boolean runInThread, ZipModel zipModel, char[] password) {
-    super(progressMonitor, runInThread, zipModel);
+  public ExtractAllFilesTask(ZipModel zipModel, char[] password, AsyncTaskParameters asyncTaskParameters) {
+    super(zipModel, asyncTaskParameters);
     this.password = password;
   }
 
@@ -44,23 +47,11 @@ public class ExtractAllFilesTask extends AbstractExtractFileTask<ExtractAllFiles
 
   @Override
   protected long calculateTotalWork(ExtractAllFilesTaskParameters taskParameters) {
-    long totalWork = 0;
-
-    for (FileHeader fileHeader : getZipModel().getCentralDirectory().getFileHeaders()) {
-      if (fileHeader.getZip64ExtendedInfo() != null &&
-          fileHeader.getZip64ExtendedInfo().getUncompressedSize() > 0) {
-        totalWork += fileHeader.getZip64ExtendedInfo().getUncompressedSize();
-      } else {
-        totalWork += fileHeader.getUncompressedSize();
-      }
-    }
-
-    return totalWork;
+    return getTotalUncompressedSizeOfAllFileHeaders(getZipModel().getCentralDirectory().getFileHeaders());
   }
 
   private ZipInputStream prepareZipInputStream(Charset charset) throws IOException {
-    splitInputStream = new SplitInputStream(getZipModel().getZipFile(),
-        getZipModel().isSplitArchive(), getZipModel().getEndOfCentralDirectoryRecord().getNumberOfThisDisk());
+    splitInputStream = UnzipUtil.createSplitInputStream(getZipModel());
 
     FileHeader fileHeader = getFirstFileHeader(getZipModel());
     if (fileHeader != null) {
