@@ -69,4 +69,14 @@ public abstract class AbstractIT {
   protected File getTestArchiveFromResources(String archiveName) {
     return TestUtils.getTestArchiveFromResources(archiveName);
   }
+
+  protected void cleanupOutputFolder() {
+    File[] filesInOutputFolder = outputFolder.listFiles();
+
+    if (filesInOutputFolder == null) {
+      return;
+    }
+
+    Arrays.stream(filesInOutputFolder).forEach(File::delete);
+  }
 }
