@@ -16,6 +16,8 @@ import net.lingala.zip4j.testutils.TestUtils;
 import net.lingala.zip4j.testutils.ZipFileVerifier;
 import net.lingala.zip4j.util.BitUtils;
 import net.lingala.zip4j.util.InternalZipConstants;
+import net.lingala.zip4j.util.RawIO;
+import net.lingala.zip4j.util.ZipVersionUtils;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.ExpectedException;
@@ -25,6 +27,7 @@ import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.List;
 import java.util.Optional;
 import java.util.stream.Collectors;
@@ -36,6 +39,8 @@ import static org.assertj.core.api.Assertions.assertThat;
 
 public class AddFilesToZipIT extends AbstractIT {
 
+  private RawIO rawIO = new RawIO();
+
   @Rule
   public ExpectedException expectedException = ExpectedException.none();
 
@@ -55,6 +60,7 @@ public class AddFilesToZipIT extends AbstractIT {
 
     ZipFileVerifier.verifyZipFileByExtractingAllFiles(generatedZipFile, outputFolder, 1);
     verifyZipFileContainsFiles(generatedZipFile, singletonList("sample.pdf"), CompressionMethod.DEFLATE, null, null);
+    verifyZipVersions(zipFile.getFileHeaders().get(0), new ZipParameters());
   }
 
   @Test
@@ -82,6 +88,7 @@ public class AddFilesToZipIT extends AbstractIT {
 
     ZipFileVerifier.verifyZipFileByExtractingAllFiles(generatedZipFile, PASSWORD, outputFolder, 1, true, CHARSET_CP_949);
     assertThat(zipFile.getFileHeaders().get(0).getFileName()).isEqualTo(koreanFileName);
+    verifyZipVersions(zipFile.getFileHeaders().get(0), zipParameters);
   }
 
   @Test
@@ -138,6 +145,7 @@ public class AddFilesToZipIT extends AbstractIT {
     ZipFileVerifier.verifyZipFileByExtractingAllFiles(generatedZipFile, PASSWORD, outputFolder, 1);
     verifyZipFileContainsFiles(generatedZipFile, singletonList("sample_text_large.txt"), CompressionMethod.STORE,
         EncryptionMethod.AES, AesKeyStrength.KEY_STRENGTH_128);
+    verifyZipVersions(zipFile.getFileHeaders().get(0), zipParameters);
   }
 
   @Test
@@ -620,6 +628,23 @@ public class AddFilesToZipIT extends AbstractIT {
     ZipFileVerifier.verifyZipFileByExtractingAllFiles(generatedZipFile, outputFolder, 13);
   }
 
+  @Test
+  public void testAddFolderWithExcludeFileFilter() throws IOException {
+    ZipFile zipFile = new ZipFile(generatedZipFile);
+    List<File> filesToExclude = Arrays.asList(
+        TestUtils.getTestFileFromResources("sample.pdf"),
+        TestUtils.getTestFileFromResources("sample_directory/favicon.ico")
+    );
+    ZipParameters zipParameters = new ZipParameters();
+    zipParameters.setIncludeRootFolder(false);
+    zipParameters.setExcludeFileFilter(filesToExclude::contains);
+
+    zipFile.addFolder(TestUtils.getTestFileFromResources(""), zipParameters);
+
+    ZipFileVerifier.verifyZipFileByExtractingAllFiles(generatedZipFile, outputFolder, 10);
+    verifyZipFileDoesNotContainFiles(generatedZipFile, Arrays.asList("sample.pdf", "sample_directory/favicon.ico"));
+  }
+
   @Test
   public void testAddStreamToZipThrowsExceptionWhenFileNameIsNull() throws IOException {
     ZipFile zipFile = new ZipFile(generatedZipFile);
@@ -849,6 +874,17 @@ public class AddFilesToZipIT extends AbstractIT {
     verifyAllFilesAreOf(fileHeaders, compressionMethod, encryptionMethod, aesKeyStrength, aesVersion);
   }
 
+  private void verifyZipFileDoesNotContainFiles(File generatedZipFile, List<String> fileNamesNotInZip) throws ZipException {
+    ZipFile zipFile = new ZipFile(generatedZipFile);
+    for (FileHeader fileHeader : zipFile.getFileHeaders()) {
+      for (String fileNameNotInZip : fileNamesNotInZip) {
+        assertThat(fileHeader.getFileName())
+            .withFailMessage("Expected file " + fileNameNotInZip + " to not be present in zip file")
+            .isNotEqualTo(fileNameNotInZip);
+      }
+    }
+  }
+
   private void verifyFoldersInZip(List<FileHeader> fileHeaders, File generatedZipFile, char[] password)
       throws IOException {
     verifyFoldersInFileHeaders(fileHeaders);
@@ -973,4 +1009,12 @@ public class AddFilesToZipIT extends AbstractIT {
 
     return compressionMethod;
   }
+
+  private void verifyZipVersions(FileHeader fileHeader, ZipParameters zipParameters) {
+    int versionMadeBy = ZipVersionUtils.determineVersionMadeBy(zipParameters, rawIO);
+    int versionNeededToExtract = ZipVersionUtils.determineVersionNeededToExtract(zipParameters).getCode();
+
+    assertThat(fileHeader.getVersionMadeBy()).isEqualTo(versionMadeBy);
+    assertThat(fileHeader.getVersionNeededToExtract()).isEqualTo(versionNeededToExtract);
+  }
 }
