@@ -141,82 +141,6 @@ public class HeaderUtilTest {
     assertThat(HeaderUtil.getFileHeader(zipModel, "SHOULD_NOT_EXIST")).isNull();
   }
 
-  @Test
-  public void testGetIndexOfFileHeaderWhenZipModelIsNullThrowsException() throws ZipException {
-    expectZipException("input parameters is null, cannot determine index of file header");
-    HeaderUtil.getIndexOfFileHeader(null, new FileHeader());
-  }
-
-  @Test
-  public void testGetIndexOfFileHeaderWhenFileHeaderlIsNullThrowsException() throws ZipException {
-    expectZipException("input parameters is null, cannot determine index of file header");
-    HeaderUtil.getIndexOfFileHeader(new ZipModel(), null);
-  }
-
-  @Test
-  public void testGetIndexOfFileHeaderWhenCentralDirectoryIsNullReturnsNegativeOne() throws ZipException {
-    ZipModel zipModel = new ZipModel();
-    zipModel.setCentralDirectory(null);
-
-    assertThat(HeaderUtil.getIndexOfFileHeader(zipModel, new FileHeader())).isEqualTo(-1);
-  }
-
-  @Test
-  public void testGetIndexOfFileHeaderWhenFileHeadersIsNullReturnsNegativeOne() throws ZipException {
-    ZipModel zipModel = new ZipModel();
-    zipModel.getCentralDirectory().setFileHeaders(null);
-
-    assertThat(HeaderUtil.getIndexOfFileHeader(zipModel, new FileHeader())).isEqualTo(-1);
-  }
-
-  @Test
-  public void testGetIndexOfFileHeaderWhenFileHeadersIsEmptyReturnsNegativeOne() throws ZipException {
-    ZipModel zipModel = new ZipModel();
-    zipModel.getCentralDirectory().setFileHeaders(Collections.emptyList());
-
-    assertThat(HeaderUtil.getIndexOfFileHeader(zipModel, new FileHeader())).isEqualTo(-1);
-  }
-
-  @Test
-  public void testGetIndexOfFileHeaderWithNullFileNameInFileHeaderThrowsException() throws ZipException {
-    expectZipException("file name in file header is empty or null, cannot determine index of file header");
-
-    ZipModel zipModel = new ZipModel();
-    zipModel.getCentralDirectory().setFileHeaders(Collections.singletonList(new FileHeader()));
-
-    HeaderUtil.getIndexOfFileHeader(zipModel, new FileHeader());
-  }
-
-  @Test
-  public void testGetIndexOfFileHeaderWithEmptyFileNameInFileHeaderThrowsException() throws ZipException {
-    expectZipException("file name in file header is empty or null, cannot determine index of file header");
-
-    ZipModel zipModel = new ZipModel();
-    zipModel.getCentralDirectory().setFileHeaders(Collections.singletonList(new FileHeader()));
-    FileHeader fileHeader = new FileHeader();
-    fileHeader.setFileName("");
-
-    HeaderUtil.getIndexOfFileHeader(zipModel, new FileHeader());
-  }
-
-  @Test
-  public void testGetIndexOfFileHeaderGetsIndexSuccessfully() throws ZipException {
-    String fileNamePrefix = "FILE_NAME_";
-    int numberOfEntriesToAdd = 10;
-    List<FileHeader> fileHeadersInZipModel = generateFileHeaderWithFileNamesWithEmptyAndNullFileNames(fileNamePrefix, numberOfEntriesToAdd);
-    ZipModel zipModel = new ZipModel();
-    zipModel.getCentralDirectory().setFileHeaders(fileHeadersInZipModel);
-
-    FileHeader fileHeaderToFind = new FileHeader();
-    for (int i = 0; i < numberOfEntriesToAdd; i++) {
-      fileHeaderToFind.setFileName(fileNamePrefix + i);
-      assertThat(HeaderUtil.getIndexOfFileHeader(zipModel, fileHeaderToFind)).isEqualTo(i);
-    }
-
-    fileHeaderToFind.setFileName(fileNamePrefix + numberOfEntriesToAdd);
-    assertThat(HeaderUtil.getIndexOfFileHeader(zipModel, fileHeaderToFind)).isEqualTo(-1);
-  }
-
   @Test
   public void testDecodeStringWithCharsetForUtf8() {
     String utf8StringToEncode = "asdäüöö";
